==> pgmarket-1.5.0.tar.gz: pgmarket-1.5.0/locale/it/global-common.inc.php <==
<?

/* (c) 2000, 2001 Marco Pratesi <pratesi@telug.it> */
/* (c) 2000 Fabio Molinari <fabio.m@mclink.it> */
/* (c) 2001 Andrew Stubbs <andrews@stusoft.com> */

global $IVA;		// taken from application.inc.php if the scope is a problem
global $currency;	// taken from application.inc.php if the scope is a problem
global $weightunity;	// taken from application.inc.php if the scope is a problem

$t->set_var(array(

// With regard to the following variables:
// each locale must include them from all the other locales...
// this makes the locales not totally independent of each other :(
"Choose_italian_language" => "Mostra sito in lingua Italiana",
"Choose_english_language" => "Go to the English version of the site",
//

"IVA" => $IVA,
"currency" => $currency,
"weightunity" => $weightunity,
"Shopping" => "Acquisto",
"Contact_us" => "Contattaci !",
"Signup_Italy" => "Iscrizione (Italia)",
"Signup_non_Italy" => "Iscrizione (Estero)",
"Companies_Signup" => "Iscrizione Aziende",
"Turn_Off_Frames" => "Disabilita frame",
"Turn_On_Frames" => "Abilita frame",
"Turn_On_Layers_Menu" => "Abilita men&ugrave; a layers",
"Turn_Off_Layers_Menu" => "Disabilita men&ugrave; a layers",
"Cart" => "Carrello",
"AdvancedSearch" => "Ricerca Avanzata",
"Search_the_Catalog" => "Cerca nel catalogo",
"At_least_a_word" => "Almeno una parola",
"All_the_words" => "Tutte le parole",
"Case_Sensitive" => "Distingui Maiuscole",
"Search_excl" => "Cerca !",
"Search_Results" => "Risultati della ricerca",
"on" => "su",
"pages" => "pagine",
"Special_Products" => "Prodotti speciali",
"footer_message" => $CFG->myname . " \"<i>Commercio elettronico - Electronic Store</i>\"",
"Home_Page" => "Pagina principale",
"PgMarket_Home_Page" => "Pagina principale di " . $CFG->myname,
"Login" => "Login",
"PgMarket_Login" => $CFG->myname . " Login",
"PgMarket_Login_Page" => $CFG->myname . ": pagina di login",
"sign_up_for_an_account_now" => "Se non sei gi&agrave; iscritto a questo negozio elettronico, iscriviti ora:",
"dont_login_back_to_home_page" => "Se non desideri ancora effettuare la procedura di login, <a href=\"".$CFG->firstpage."\">clicca qui</a> per tornare alla pagina principale (home page).",
"Logout" => "Logout",
"Action" => "Azione",
"back" => "indietro",
"BACK" => "INDIETRO",
"Brand" => "Marca",
"Discount" => "Sconto",
"Starting_from" => "a partire da",
"Items" => "pezzi",
"Weight" => "Peso",
"View_product_details" => "Mostra dettagli del prodotto",
"Category" => "Categoria",
"Categories" => "Categorie",
"The_category" => "La categoria",
"Parent" => "Padre",
"Product" => "Prodotto",
"Products" => "Prodotti",
"The_product" => "Il prodotto",
"Details" => "Dettagli",
"None_Female_Singular" => "Nessuna",
"None_Male_Singular" => "Nessuno",
"Categories_Browsing" => "Navigazione delle Categorie",
"Customer" => "Cliente",
"Customer_Info" => "Informazioni sul cliente",
"Phone_Contact" => "Recapito telefonico",
"Address" => "Via/Piazza",
"Number" => "Numero",
"City" => "Comune",
"Country" => "Citt&agrave;",
"Zip_Code" => "CAP",
"Phone" => "Telefono",
"Fax" => "Fax",
"MobilePhone" => "Cellulare",
"E_mail" => "E-mail",
"Date" => "Data",
"current_date" => date("d-m-Y"),
"Bill_to" => "Venduto a",
"Total_weight" => "Peso totale",
"Contact" => "Recapito",
"Total" => "Totale",
"Order" => "Ordine",
"Orders" => "Ordini",
"No_Orders" => "Nessun Ordine",
"No_Such_Order" => "Non c'&egrave; nessun ordine con l'identificativo richiesto",
"The_order" => "L'ordine",
"Ordered" => "Ordinato",
"Ordered_By" => "Ordinato da",
"Order_Details" => "Dettagli dell'ordine",
"Order_State" => "Stato dell'ordine",
"Orders_States" => "Stati degli ordini",
"ID" => "ID",
"ID_and_State" => "ID - Stato",
"Amount" => "Ammontare",
"Payment_Methods" => "Metodi di pagamento",
"Cash_On_Delivery" => "Contrassegno",
"Credit_Card" => "Carta di Credito",
"Comments_and_Special_Instructions" => "Commenti / Istruzioni speciali",
"Qty" => "Q.t&agrave;",
"Sub_Total" => "Sub Totale",
"Delivery" => "Spedizione",
"Purchase_Now" => "Acquista ora",
"Order_Completed_Successfully" => "Ordine completato con successo",
"submission_to_banca_sella" => "Pagamento con Carta di Credito",
"Shopping_Catalog" => "Catalogo dei prodotti in vendita",
"Product_Details" => "Dettagli del prodotto",
"Product_Not_Found" => "Prodotto non trovato",
"Checkout" => "Cassa",
"Shopping_Cart" => "Carrello della spesa",
"Image" => "Immagine",
"Remove" => "Rimuovi",
"Delete" => "Elimina",
"Edit" => "Modifica",
"Name" => "Nome",
"Description" => "Descrizione",
"Extended_Description" => "Descrizione estesa",
"Price" => "Prezzo",
"Current_Price" => "Prezzo attuale",
"Purchase_Price" => "Prezzo d'acquisto",
"Starting_from" => "a partire da",
"Reset_Form" => "Svuota form",
"Brand" => "Marca",
"Brands" => "Marche",
"The_brand" => "La marca",
"User" => "Utente",
"Username" => "Username",
"Min_Username_Length" => "(min. ". $SESSION["username_length_min"] . " caratteri)",
"Password" => "Password",
"Old_Password" => "Vecchia Password",
"New_Password" => "Nuova Password",
"Password_Confirm" => "Password (conferma)",
"Confirm_Password" => "Conferma Password",
"Change_Password" => "Modifica Password",
"First_Name" => "Nome",
"Last_Name" => "Cognome",
"Company_Name" => "Ragione Sociale",
"Fiscal_Code" => "Codice Fiscale",
"Company_identification_number" => "Partita IVA",
"Company_Id_N" => "Partita IVA",
"I_agree_to_the_usage_of_the_data_provided" => "Autorizzo il trattamento dei dati qui forniti",
"I_accept_advertising_material" => "Accetto materiale pubblicitario",
"I_agree_to_the_use_of_my_personal_data" => "Autorizzo il trattamento dei miei dati personali",
"Message" => "Messaggio",
"Send" => "Spedisci",
"Notes" => "Annotazioni",
"Contact_Us" => "Contattaci via E-mail",
"Contact_Successful" => "E-mail inviata con successo",
"Password_Change_Successful" => "Modifica della password effettuata con successo",
"Change_Settings" => "Modifica Impostazioni",
"Settings_Change_Successful" => "Impostazioni modificate con successo",
"Signup" => "Iscrizione",
"Signup_Successful" => "Iscrizione effettuata con successo",
"Orders_Log_ca" => "Diario degli ordini - Contrassegno",
"Orders_Log_cc" => "Diario degli ordini - Carta di Credito",
"has_been_added_female_singular" => "&egrave; stata creata",
"has_been_added_male_singular" => "&egrave; stato creato",
"has_been_updated_female_singular" => "&egrave; stata modificata",
"has_been_updated_male_singular" => "&egrave; stato modificato",
"has_been_deleted_female_singular" => "&egrave; stata eliminata",
"has_been_deleted_male_singular" => "&egrave; stato eliminato",
"there_are_errors" => "Ci sono errori nei parametri sottomessi",
"Errors" => "Errori",

));

?>

==> pgmarket-1.5.2.tar.gz: pgmarket-1.5.2/locale/it/global-common.inc.php <==
<?php

/* (c) 2000, 2001 Marco Pratesi <pratesi@telug.it> */
/* (c) 2000 Fabio Molinari <fabio.m@mclink.it> */
/* (c) 2001 Andrew Stubbs <andrews@stusoft.com> */

global $IVA;		// taken from application.inc.php if the scope is a problem
global $currency;	// taken from application.inc.php if the scope is a problem
global $weightunity;	// taken from application.inc.php if the scope is a problem

$t->set_var(array(

// With regard to the following variables:
// each locale must include them from all the other locales...
// this makes the locales not totally independent of each other :(
"Choose_italian_language" => "Mostra sito in lingua Italiana",
"Choose_english_language" => "Go to the English version of the site",
//

"IVA" => $IVA,
"currency" => $currency,
"weightunity" => $weightunity,
"Shopping" => "Acquisto",
"Contact_us" => "Contattaci !",
"Signup_Italy" => "Iscrizione (Italia)",
"Signup_non_Italy" => "Iscrizione (Estero)",
"Companies_Signup" => "Iscrizione Aziende",
"Turn_Off_Frames" => "Disabilita frame",
"Turn_On_Frames" => "Abilita frame",
"Turn_On_Layers_Menu" => "Abilita men&ugrave; a layers",
"Turn_Off_Layers_Menu" => "Disabilita men&ugrave; a layers",
"Cart" => "Carrello",
"AdvancedSearch" => "Ricerca Avanzata",
"Search_the_Catalog" => "Cerca nel catalogo",
"At_least_a_word" => "Almeno una parola",
"All_the_words" => "Tutte le parole",
"Case_Sensitive" => "Distingui Maiuscole",
"Search_excl" => "Cerca !",
"Search_Results" => "Risultati della ricerca",
"on" => "su",
"pages" => "pagine",
"Special_Products" => "Prodotti speciali",
"footer_message" => "$CFG->myname" . " \"<i>Commercio elettronico - Electronic Store</i>\"",
"Home_Page" => "Pagina principale",
"PgMarket_Home_Page" => "Pagina principale di " . "$CFG->myname",
"Login" => "Login",
"PgMarket_Login" => "$CFG->myname" . " Login",
"PgMarket_Login_Page" => "$CFG->myname" . ": pagina di login",
"sign_up_for_an_account_now" => "Se non sei gi&agrave; iscritto a questo negozio elettronico, iscriviti ora:",
"dont_login_back_to_home_page" => "Se non desideri ancora effettuare la procedura di login, <a href=\"" . "$CFG->firstpage" . "\">clicca qui</a> per tornare alla pagina principale (home page).",
"Logout" => "Logout",
"Action" => "Azione",
"back" => "indietro",
"BACK" => "INDIETRO",
"Discount" => "Sconto",
"Starting_from" => "a partire da",
"Items" => "pezzi",
"Weight" => "Peso",
"View_product_details" => "Mostra dettagli del prodotto",
"Category" => "Categoria",
"Categories" => "Categorie",
"The_category" => "La categoria",
"Parent" => "Padre",
"Product" => "Prodotto",
"Products" => "Prodotti",
"The_product" => "Il prodotto",
"Product_Code" => "Codice",
"Details" => "Dettagli",
"None_Female_Singular" => "Nessuna",
"None_Male_Singular" => "Nessuno",
"Categories_Browsing" => "Navigazione delle Categorie",
"Customer" => "Cliente",
"Customer_Info" => "Informazioni sul cliente",
"Phone_Contact" => "Recapito telefonico",
"Address" => "Via/Piazza",
"Number" => "Numero",
"City" => "Comune",
"Country" => "Citt&agrave;",
"Zip_Code" => "CAP",
"Phone" => "Telefono",
"Fax" => "Fax",
"MobilePhone" => "Cellulare",
"E_mail" => "E-mail",
"Date" => "Data",
"current_date" => date("d-m-Y"),
"Bill_to" => "Venduto a",
"Total_weight" => "Peso totale",
"Contact" => "Recapito",
"Total" => "Totale",
"Order" => "Ordine",
"Orders" => "Ordini",
"No_Orders" => "Nessun Ordine",
"No_Such_Order" => "Non c'&egrave; nessun ordine con l'identificativo richiesto",
"The_order" => "L'ordine",
"Ordered" => "Ordinato",
"Ordered_By" => "Ordinato da",
"Order_Details" => "Dettagli dell'ordine",
"Order_State" => "Stato dell'ordine",
"Orders_States" => "Stati degli ordini",
"ID" => "ID",
"ID_and_State" => "ID - Stato",
"Amount" => "Ammontare",
"Payment_Methods" => "Metodi di pagamento",
"Cash_On_Delivery" => "Contrassegno",
"Credit_Card" => "Carta di Credito",
"Comments_and_Special_Instructions" => "Commenti / Istruzioni speciali",
"Qty" => "Q.t&agrave;",
"Sub_Total" => "Sub Totale",
"Delivery" => "Spedizione",
"Purchase_Now" => "Acquista ora",
"Order_Completed_Successfully" => "Ordine completato con successo",
"submission_to_banca_sella" => "Pagamento con Carta di Credito",
"Shopping_Catalog" => "Catalogo dei prodotti in vendita",
"Product_Details" => "Dettagli del prodotto",
"Product_Not_Found" => "Prodotto non trovato",
"Checkout" => "Cassa",
"Shopping_Cart" => "Carrello della spesa",
"Image" => "Immagine",
"Remove" => "Rimuovi",
"Delete" => "Elimina",
"Edit" => "Modifica",
"Name" => "Nome",
"Description" => "Descrizione",
"Extended_Description" => "Descrizione estesa",
"Price" => "Prezzo",
"Current_Price" => "Prezzo attuale",
"Purchase_Price" => "Prezzo d'acquisto",
"Reset_Form" => "Svuota form",
"Brand" => "Marca",
"Brands" => "Marche",
"The_brand" => "La marca",
"User" => "Utente",
"Username" => "Username",
"Min_Username_Length" => "(min. ". $SESSION["username_length_min"] . " caratteri)",
"Password" => "Password",
"Old_Password" => "Vecchia Password",
"New_Password" => "Nuova Password",
"Password_Confirm" => "Password (conferma)",
"Confirm_Password" => "Conferma Password",
"Change_Password" => "Modifica Password",
"First_Name" => "Nome",
"Last_Name" => "Cognome",
"Company_Name" => "Ragione Sociale",
"Fiscal_Code" => "Codice Fiscale",
"Company_identification_number" => "Partita IVA",
"Company_Id_N" => "Partita IVA",
"I_agree_to_the_usage_of_the_data_provided" => "Autorizzo il trattamento dei dati qui forniti",
"I_accept_advertising_material" => "Accetto materiale pubblicitario",
"I_agree_to_the_use_of_my_personal_data" => "Autorizzo il trattamento dei miei dati personali",
"Message" => "Messaggio",
"Send" => "Spedisci",
"Notes" => "Annotazioni",
"Contact_Us" => "Contattaci via E-mail",
"Contact_Successful" => "E-mail inviata con successo",
"Password_Change_Successful" => "Modifica della password effettuata con successo",
"Change_Settings" => "Modifica Impostazioni",
"Settings_Change_Successful" => "Impostazioni modificate con successo",
"Signup" => "Iscrizione",
"Signup_Successful" => "Iscrizione effettuata con successo",
"Orders_Log_ca" => "Diario degli ordini - Contrassegno",
"Orders_Log_cc" => "Diario degli ordini - Carta di Credito",
"has_been_added_female_singular" => "&egrave; stata creata",
"has_been_added_male_singular" => "&egrave; stato creato",
"has_been_updated_female_singular" => "&egrave; stata modificata",
"has_been_updated_male_singular" => "&egrave; stato modificato",
"has_been_deleted_female_singular" => "&egrave; stata eliminata",
"has_been_deleted_male_singular" => "&egrave; stato eliminato",
"there_are_errors" => "Ci sono errori nei parametri sottomessi",
"Errors" => "Errori",

));

?>
